@@ -1,29 +1,17 @@
 OC.L10N.register(
     "contacts",
     {
-    "All contacts" : "كل الجهات",
     "Details" : "التفاصيل",
+    "All contacts" : "كل جهات الإتصال",
     "Contacts" : "جهات الاتصال",
     "Copy to full name" : "انسخ إلى الإسم الكامل",
-    "Upload a new picture" : "تحميل صورة جديدة",
-    "Choose from Files" : "اختر من الملفات",
-    "Download picture" : "تنزيل الصورة",
-    "Delete picture" : "حذف الصورة",
-    "Invalid image" : "الصورة غير صالحة",
-    "Name" : "الاسم",
-    "Company" : "الشركة",
-    "Title" : "العنوان",
     "Download" : "تحميل",
-    "Delete" : "حذف",
-    "Cancel" : "إلغاء",
-    "Address book" : "دفتر العناوين",
     "Groups" : "مجموعات",
-    "New contact" : "جهة إتصال جديدة",
-    "No results" : "دون أية نتيجة",
-    "Last modified" : "آخر تعديل",
+    "Group name" : "إسم الفريق",
     "Rename" : "تعديل الإسم",
     "Enabled" : "مفعلة",
     "Disabled" : "معطّل",
+    "Delete" : "حذف",
     "Copy link" : "نسخ الرابط",
     "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
     "can edit" : "يمكن التعديل",
@@ -31,10 +19,30 @@ OC.L10N.register(
     "First name" : "الإسم",
     "Last name" : "اللقب",
     "Display name" : "الاسم المعروض",
-    "Group name" : "إسم الفريق",
-    "Not grouped" : "غير مصنف",
+    "Last modified" : "آخر تعديل",
+    "Upload a new picture" : "تحميل صورة جديدة",
+    "Choose from Files" : "اختر من الملفات",
+    "Download picture" : "تنزيل الصورة",
+    "Delete picture" : "حذف الصورة",
+    "Invalid image" : "الصورة غير صالحة",
+    "Image is too big (max 1MB)." : "حجم الصورة كبير جداً (الحجم الأقصى 1MB)",
+    "Error while processing the picture." : "حدث خطأ أثناء معالجة الصورة.",
+    "Avatar already up to date" : "الصورة الرمزية محدثة بالفعل",
+    "Avatar download failed" : "فشل تحميل الصورة الرمزية",
+    "No contact selected" : "لم يتم تحديد جهة اتصال",
+    "Select a contact on the list to begin" : "حدد جهة اتصال في القائمة للبدء",
+    "Name" : "الاسم",
+    "Company" : "الشركة",
+    "Title" : "العنوان",
+    "Cancel" : "إلغاء",
+    "Address book" : "دفتر العناوين",
+    "New contact" : "جهة إتصال جديدة",
+    "No results" : "دون أية نتيجة",
+    "Select option" : "حدد الخيار",
     "Close" : "إغلاق",
     "Import" : "استيراد",
+    "Not grouped" : "غير مصنف",
+    "Email" : "البريد الإلكترونى",
     "Nickname" : "كنية.\nلقب.",
     "Detailed name" : "الإسم بالتفصيل",
     "Additional names" : "الأسماء الإضافية",
@@ -56,7 +64,6 @@ OC.L10N.register(
     "Birthday" : "عيد ميلاد",
     "Anniversary" : "ذكرى سنوية",
     "Date of death" : "تاريخ الوفاة",
-    "Email" : "البريد الإلكترونى",
     "Instant messaging" : "المراسلة الفورية",
     "Phone" : "الهاتف",
     "Mobile" : "الهاتف المحمول",
