@@ -1,48 +1,21 @@
 OC.L10N.register(
     "contacts",
     {
-    "All contacts" : "Todos los contactos",
     "Details" : "Detalles",
+    "All contacts" : "Todos los contactos",
     "Contacts" : "Contactos",
     "A contacts app for Nextcloud" : "Una aplicación de contactos para Nextcloud",
     "Copy to full name" : "Copiar a nombre completo",
     "Omit year" : "Omitir año",
-    "Add new property" : "Añadir nueva propiedad",
-    "Choose property type" : "Elija el tipo de propiedad",
-    "Upload a new picture" : "Subir una nueva imagen",
-    "Download picture" : "Descargar imágen",
-    "Choose from files" : "Elige entre archivos",
-    "Invalid image" : "Imagen inválida",
-    "Image is too big (max 1MB)." : "La imagen es demasiado grande (máximo 1MB).",
-    "No contact selected" : "Contacto no seleccionado",
-    "Select a contact on the list to begin" : "Seleccione un contacto en la lista para comenzar",
-    "Name" : "Nombre",
-    "Company" : "Empresa",
-    "Title" : "Título",
     "Download" : "Descargar",
-    "Generate QR Code" : "Generar código QR",
-    "Delete" : "Borrar",
-    "Cancel" : "Cancelar",
-    "This contact is not yet synced. Edit it to save it to the server." : "Este contacto aún no está sincronizado. Edítalo para guardarlo en el servidor.",
-    "This contact is in read-only mode. You do not have permission to edit this contact." : "Este contacto está en modo de sólo lectura. No tienes permiso para editar este contacto.",
-    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "El contacto que intentabas editar ha cambiado. Por favor actualice manualmente el contacto. Cualquier otra edición será descartada.",
-    "Address book" : "libreta de direcciones",
     "Groups" : "Grupos",
-    "New contact" : "Nuevo contacto",
-    "The contact doesn't exists anymore on the server." : "El contacto ya no existe en el servidor.",
-    "No results" : "Sin resultados",
-    "Select type" : "Seleccionar tipo",
-    "Select Date" : "Seleccionar fecha",
-    "Add contact in group" : "Añadir contacto en grupo",
-    "Last modified" : "Última modificación",
-    "Select option" : "Seleccionar opción",
+    "Group name" : "Nombre del grupo",
     "Rename" : "Renombrar",
     "Enabled" : "Habilitado",
     "Disabled" : "Deshabilitado",
+    "Delete" : "Borrar",
     "Copied" : "Copiado",
-    "Can not copy" : "No se puede copiar",
     "Copy link" : "Copiar enlace",
-    "Delete {addressbook} ?" : "¿Borrar {addressbook} ?",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "No users or groups" : "No hay usuarios ni grupos.",
     "can edit" : "poder editar",
@@ -51,13 +24,38 @@ OC.L10N.register(
     "First name" : "Nombre",
     "Last name" : "Apellido",
     "Display name" : "Nombre para mostrar",
+    "Last modified" : "Última modificación",
     "Sort by {sorting}" : "Ordenar por {sorting}",
-    "Group name" : "Nombre del grupo",
-    "Not grouped" : "No agrupado",
+    "Add new property" : "Añadir nueva propiedad",
+    "Choose property type" : "Elija el tipo de propiedad",
+    "Upload a new picture" : "Subir una nueva imagen",
+    "Download picture" : "Descargar imágen",
+    "Invalid image" : "Imagen inválida",
+    "Image is too big (max 1MB)." : "La imagen es demasiado grande (máximo 1MB).",
+    "No contact selected" : "Contacto no seleccionado",
+    "Select a contact on the list to begin" : "Seleccione un contacto en la lista para comenzar",
+    "Name" : "Nombre",
+    "Company" : "Empresa",
+    "Title" : "Título",
+    "Cancel" : "Cancelar",
+    "This contact is not yet synced. Edit it to save it to the server." : "Este contacto aún no está sincronizado. Edítalo para guardarlo en el servidor.",
+    "This contact is in read-only mode. You do not have permission to edit this contact." : "Este contacto está en modo de sólo lectura. No tienes permiso para editar este contacto.",
+    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "El contacto que intentabas editar ha cambiado. Por favor actualice manualmente el contacto. Cualquier otra edición será descartada.",
+    "Address book" : "libreta de direcciones",
+    "New contact" : "Nuevo contacto",
+    "The contact doesn't exists anymore on the server." : "El contacto ya no existe en el servidor.",
+    "No results" : "Sin resultados",
+    "Select type" : "Seleccionar tipo",
+    "Select Date" : "Seleccionar fecha",
+    "Add contact in group" : "Añadir contacto en grupo",
+    "Select option" : "Seleccionar opción",
     "Unable to create the contact." : "No se puede crear el contacto.",
     "Contact not found" : "Contacto no encontrado",
     "Close" : "Cerrar",
     "Import" : "Importar",
+    "Not grouped" : "No agrupado",
+    "Email" : "Correo electrónico",
+    "Contact" : "Contacto",
     "Nickname" : "Apodo",
     "Detailed name" : "Nombre detallado",
     "Additional names" : "Nombres adicionales",
@@ -80,7 +78,6 @@ OC.L10N.register(
     "Birthday" : "Fecha de nacimiento",
     "Anniversary" : "Aniversario",
     "Date of death" : "Fecha de defunción",
-    "Email" : "Correo electrónico",
     "Instant messaging" : "Mensajería instantánea",
     "Phone" : "Teléfono fijo",
     "Mobile" : "Teléfono móvil",
@@ -106,7 +103,6 @@ OC.L10N.register(
     "Colleague" : "Colega",
     "Manager" : "Gerente",
     "Assistant" : "Asistente",
-    "Contact" : "Contacto",
     "Agent" : "Agente",
     "Emergency" : "Emergencia",
     "Co-worker" : "Co-trabajador",
