@@ -1,34 +1,74 @@
 OC.L10N.register(
     "contacts",
     {
-    "All contacts" : "すべての連絡先",
     "Details" : "詳細",
+    "All contacts" : "すべての連絡先",
     "Contacts" : "連絡先",
     "A contacts app for Nextcloud" : "Nextcloud の連絡先アプリ",
     "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud の連絡先アプリは、 Nextcloud の CardDAV サーバーのユーザーインターフェースです。 さまざまなデバイスの連絡先を Nextcloud で簡単に同期し、オンラインで編集できます。\n\n*🚀**他の Nextcloud アプリケーションとの統合！**現在、メールとカレンダー - 今後の予定です。\n*🎉**誕生日を忘れないでください！**あなたの Nextcloud カレンダーで誕生日やその他の定期的なイベントを同期できます。\n*👥** 連絡先の共有！**あなたの友達や同僚とあなたの連絡先を共有したいですか？ 問題ない！\n*🙈**私たちは車輪を再発明していません！**偉大でオープンな SabreDAV ライブラリをベースにしています。",
     "Copy to full name" : "フルネームをコピー",
     "Omit year" : "年を省略する",
+    "Loading contacts …" : "連絡先を読み込み中...",
+    "There are no contacts yet" : "連絡先はまだありません",
+    "Create contact" : "連絡先を作成",
+    "Create contacts" : "連絡先を作成",
+    "Add contacts" : "連絡先を追加",
+    "Loading …" : "読み込み中…",
+    "Download" : "ダウンロード",
+    "Groups" : "グループ",
+    "Create a new group" : "新規グループを作成",
+    "Group name" : "グループ名",
+    "This group already exists" : "このグループはすでに存在しています",
+    "Rename" : "名前を変更",
+    "Enabled" : "有効",
+    "Disabled" : "無効",
+    "Delete" : "削除",
+    "Copied" : "コピーしました",
+    "Copy link" : "リンクをコピー",
+    "Toggling of address book was not successful" : "アドレス帳の切り替えに失敗",
+    "This will delete the address book and every contacts within it" : "これはアドレス帳とその中のすべての連絡先を削除します",
+    "Deletion of address book was not successful." : "アドレス帳の削除に失敗しました。",
+    "Renaming of address book was not successful." : "アドレス帳の名前変更に失敗しました。",
+    "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num} 個のエンティティと共有"],
+    "Share with users or groups" : "ユーザーまたはグループと共有する",
+    "No users or groups" : "ユーザーまたはグループはありません",
+    "can edit" : "編集を許可",
+    "Unable to delete the share" : "共有を削除できません",
+    "Unable to change permissions" : "権限を変更できません。",
+    "Import contacts" : "連絡先のインポート",
+    "Select local file" : "ローカルファイルの選択",
+    "Importing is disabled because there are no address books available" : "使用可能なアドレス帳がないため、インポートは無効です",
+    "Choose a vCard file to import" : "インポートするvCardファイルを選択",
+    "Address book name" : "アドレス帳名",
+    "An error occurred, unable to create the address book" : "エラーが発生し、アドレス帳を作成できませんでした。",
+    "First name" : "名",
+    "Last name" : "姓",
+    "Phonetic first name" : "めい",
+    "Phonetic last name" : "せい",
+    "Display name" : "表示名",
+    "Last modified" : "最終更新日",
+    "Sort by {sorting}" : "{sorting} で整列",
+    "Update avatars from social media" : "SNSでアバターをアップデート",
     "Add new property" : "新しいプロパティを追加する",
     "Choose property type" : "プロパティの種類を選択",
     "Upload a new picture" : "新しい写真をアップロードする",
-    "Choose from files" : "ファイルから選択",
+    "Choose from Files" : "ファイルから選択",
     "Download picture" : "画像をダウンロード",
     "Delete picture" : "画像を削除",
     "Invalid image" : "無効な画像",
     "Image is too big (max 1MB)." : "画像容量が大きすぎます (最大1 MB)",
     "Pick an avatar" : "アバターを選択",
     "Error while processing the picture." : "画像の加工中にエラーが発生しました",
+    "Avatar downloaded from social network" : "SNSでダウンロード済みのアバター",
+    "Avatar already up to date" : "アバターはすでに最新です",
+    "Avatar download failed" : "アバターのダウンロードに失敗しました",
     "No contact selected" : "連絡先が選択されていません",
     "Select a contact on the list to begin" : "開始するには、リストの連絡先を選択してください",
     "Name" : "名前",
     "Company" : "会社",
     "Title" : "タイトル",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "この連絡先は変更され、修正を受信しました。内容を確認してクリックで保存してください。",
-    "Download" : "ダウンロード",
     "Clone contact" : "連絡先の複製",
-    "Generate QR Code" : "QRコードを生成",
-    "Delete" : "削除",
-    "Contact vCard as qrcode" : "QR コードの vCard の連絡先",
     "Pick an address book" : "アドレス帳を選ぶ",
     "Select address book" : "アドレス帳を選ぶ",
     "Cancel" : "キャンセル",
@@ -36,65 +76,30 @@ OC.L10N.register(
     "This contact is in read-only mode. You do not have permission to edit this contact." : "この連絡先は読み取り専用モードです。 この連絡先を編集する権限がありません。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "編集しようとした連絡先が変更されました。 連絡先を手動で更新してください。 それ以上の編集は破棄されます。",
     "Address book" : "アドレス帳",
-    "Groups" : "グループ",
     "New contact" : "新しい連絡先",
     "Syntax error. Cannot open the contact." : "構文エラー。 連絡先を開けません",
     "The contact doesn't exists anymore on the server." : "連絡先はサーバーに存在しません。",
+    "Unable to retrieve the contact from the server, please check your network connection." : "サーバーから連絡先を取得できないので、ネットワークの接続をご確認ください。",
     "An error occurred while trying to move the contact" : "連絡先の移動中にエラーが発生しました",
     "An error occurred while trying to copy the contact" : "連絡先のコピー中にエラーが発生しました",
     "Remove {type}" : "{type} を削除",
-    "Loading …" : "読み込み中…",
     "No results" : "該当なし",
     "Add to group" : "グループに追加",
     "Select type" : "タイプを選択",
     "Select Date" : "日付を選択",
     "Add contact in group" : "グループに連絡先を追加",
-    "Last modified" : "最終更新日",
     "Select option" : "オプションを選択",
-    "Rename" : "名前を変更",
-    "Enabled" : "有効",
-    "Disabled" : "無効",
-    "Copied" : "コピーしました",
-    "Can not copy" : "コピーできません",
-    "Copy link" : "リンクをコピー",
-    "Toggling of address book was not successful" : "アドレス帳の切り替えに失敗",
-    "This will delete the address book and every contacts within it" : "これはアドレス帳とその中のすべての連絡先を削除します",
-    "Delete {addressbook} ?" : "{アドレス帳}を削除しますか？",
-    "Deletion of address book was not successful." : "アドレス帳の削除に失敗しました。",
-    "Renaming of address book was not successful." : "アドレス帳の名前変更に失敗しました。",
-    "Address book copied to clipboard" : "アドレス帳をクリップボードにコピー",
-    "Address book was not copied to clipboard." : "アドレス帳がクリップボードにコピーされませんでした。",
-    "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num} 個のエンティティと共有"],
-    "Share with users or groups" : "ユーザーまたはグループと共有する",
-    "No users or groups" : "ユーザーまたはグループはありません",
-    "can edit" : "編集を許可",
-    "Import contacts" : "連絡先のインポート",
-    "Select local file" : "ローカルファイルの選択",
-    "Import from files" : "ファイルからインポート ",
-    "Importing is disabled because there are no address books available" : "使用可能なアドレス帳がないため、インポートは無効です",
-    "Choose a vCard file to import" : "インポートするvCardファイルを選択",
-    "Address book name" : "アドレス帳名",
-    "First name" : "名",
-    "Last name" : "姓",
-    "Phonetic first name" : "めい",
-    "Phonetic last name" : "せい",
-    "Display name" : "表示名",
-    "Sort by {sorting}" : "{sorting} で整列",
-    "Add contacts" : "連絡先を追加",
-    "+ New group" : "+ 新規グループ",
-    "Create a new group" : "新規グループを作成",
-    "Group name" : "グループ名",
-    "Loading contacts …" : "連絡先を読み込み中...",
-    "Create contact" : "連絡先を作成",
-    "Create contacts" : "連絡先を作成",
-    "Not grouped" : "グループ化されていません",
     "Unable to create the contact." : "連絡先を追加できません。",
     "Contact not found" : "連絡先がありません",
-    "Group not found" : "グループが見つかりません",
     "Close" : "閉じる",
+    "_{count} error_::_{count} errors_" : ["{count} つのエラー"],
     "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n の連絡先をインポートしています。"],
     "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["{アドレス帳}に %n 連絡先のインポートが完了しました"],
     "Import" : "インポート",
+    "Not grouped" : "グループ化されていません",
+    "Recently contacted" : "最近連絡した",
+    "Email" : "メール",
+    "Contact" : "連絡先",
     "Nickname" : "ニックネーム",
     "Detailed name" : "詳細名",
     "Additional names" : "ミドルネーム",
@@ -117,7 +122,6 @@ OC.L10N.register(
     "Birthday" : "誕生日",
     "Anniversary" : "記念日",
     "Date of death" : "命日",
-    "Email" : "メール",
     "Instant messaging" : "インスタントメッセージ",
     "Phone" : "電話番号",
     "Mobile" : "携帯",
@@ -131,6 +135,7 @@ OC.L10N.register(
     "Car" : "自動車",
     "Work pager" : "ワークページャー",
     "Social network" : "ソーシャルネットワーク",
+    "Relationship to you" : "あなたとの関係",
     "Spouse" : "配偶者",
     "Child" : "子供",
     "Mother" : "母親",
@@ -143,7 +148,6 @@ OC.L10N.register(
     "Colleague" : "同僚",
     "Manager" : "マネージャー",
     "Assistant" : "アシスタント",
-    "Contact" : "連絡先",
     "Agent" : "エージェント",
     "Emergency" : "緊急",
     "Co-worker" : "同僚",
@@ -155,7 +159,8 @@ OC.L10N.register(
     "Timezone" : "タイムゾーン",
     "Spoken languages" : "話せる言語",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed}連絡先の読み込みができませんでした。"],
-    "Your web browser is out of date" : "ウェブブラウザが古いです",
+    "Unable to delete contact" : "連絡先を削除できません。",
+    "Your web browser is out of date" : "Webブラウザーが古いです",
     "This application is not compatible with Internet Explorer" : "このアプリはInternet Explorerと互換性がありません"
 },
 "nplurals=1; plural=0;");
