@@ -1,11 +1,31 @@
 OC.L10N.register(
     "contacts",
     {
-    "All contacts" : "Alle kontakter",
     "Details" : "Detaljer",
+    "All contacts" : "Alle kontakter",
     "Contacts" : "Kontakter",
     "A contacts app for Nextcloud" : "En kontaktapp for Nextcloud",
     "Copy to full name" : "Kopier til fullt navn",
+    "Loading contacts …" : "Laster inn kontakter…",
+    "Loading …" : "Laster...",
+    "Download" : "Last ned",
+    "Groups" : "Grupper",
+    "Group name" : "Gruppenavn",
+    "Rename" : "Gi nytt navn",
+    "Enabled" : "Aktiver",
+    "Disabled" : "Deaktiver",
+    "Delete" : "Slett",
+    "Copied" : "Kopiert",
+    "Copy link" : "Kopier lenke",
+    "Share with users or groups" : "Del med brukere eller grupper",
+    "No users or groups" : "Ingen brukere eller grupper",
+    "can edit" : "kan redigere",
+    "Address book name" : "Adresseboksnavn",
+    "First name" : "Fornavn",
+    "Last name" : "Etternavn",
+    "Display name" : "Visningsnavn",
+    "Last modified" : "Sist endret",
+    "Sort by {sorting}" : "Sorter etter {sorting}",
     "Add new property" : "Legg til felt",
     "Choose property type" : "Velg felttype",
     "Upload a new picture" : "Last opp et nytt bilde",
@@ -16,45 +36,25 @@ OC.L10N.register(
     "Name" : "Navn",
     "Company" : "Bedrift",
     "Title" : "Tittel",
-    "Download" : "Last ned",
-    "Delete" : "Slett",
     "Cancel" : "Avbryt",
     "This contact is not yet synced. Edit it to save it to the server." : "Denne kontakt er enda ikke synkronisert. Rediger den for å lagre den på serveren.",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "Kontakten er skrivebeskyttet. Du har ikke tillatelse til å redigere denne kontakten.",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakten du prøvde å redigere, har blitt endret. Vennligst oppdater manuelt. Ytterligere endringer vil ikke kunne lagres.",
     "Address book" : "Adressebok",
-    "Groups" : "Grupper",
     "New contact" : "Ny kontakt",
     "Syntax error. Cannot open the contact." : "Syntaksfeil. Kan ikke åpne kontakten.",
-    "Loading …" : "Laster...",
     "No results" : "Ingen resultater",
     "Select type" : "Velg type",
     "Select Date" : "Velg dato",
     "Add contact in group" : "Legg kontakt til gruppe",
-    "Last modified" : "Sist endret",
     "Select option" : "Velg innstilling",
-    "Rename" : "Gi nytt navn",
-    "Enabled" : "Aktiver",
-    "Disabled" : "Deaktiver",
-    "Copied" : "Kopiert",
-    "Can not copy" : "Kan ikke kopiere",
-    "Copy link" : "Kopier lenke",
-    "Delete {addressbook} ?" : "Slette {addressbook} ?",
-    "Share with users or groups" : "Del med brukere eller grupper",
-    "No users or groups" : "Ingen brukere eller grupper",
-    "can edit" : "kan redigere",
-    "Address book name" : "Adresseboksnavn",
-    "First name" : "Fornavn",
-    "Last name" : "Etternavn",
-    "Display name" : "Visningsnavn",
-    "Sort by {sorting}" : "Sorter etter {sorting}",
-    "Group name" : "Gruppenavn",
-    "Loading contacts …" : "Laster inn kontakter…",
-    "Not grouped" : "Ikke gruppert",
     "Unable to create the contact." : "Kontakten kunne ikke opprettes.",
     "Contact not found" : "Kontakten ble ikke funnet",
     "Close" : "Lukk",
     "Import" : "Importer",
+    "Not grouped" : "Ikke gruppert",
+    "Email" : "E-post",
+    "Contact" : "Kontakt",
     "Nickname" : "Kallenavn",
     "Detailed name" : "Detaljert navn",
     "Additional names" : "Ev. mellomnavn",
@@ -77,7 +77,6 @@ OC.L10N.register(
     "Birthday" : "Bursdag",
     "Anniversary" : "Jubileum",
     "Date of death" : "Dødsdato",
-    "Email" : "E-post",
     "Instant messaging" : "Direktemeldinger",
     "Phone" : "Telefon",
     "Mobile" : "Mobil",
@@ -103,7 +102,6 @@ OC.L10N.register(
     "Colleague" : "Kollega",
     "Manager" : "Sjef",
     "Assistant" : "Assistent",
-    "Contact" : "Kontakt",
     "Emergency" : "Nødstilfelle",
     "Co-worker" : "Kollega",
     "Gender" : "Kjønn",
