@@ -1,23 +1,18 @@
 OC.L10N.register(
     "contacts",
     {
-    "Contacts" : "Contacte",
-    "All contacts" : "Toate contactele",
     "Details" : "Detalii",
-    "Invalid image" : "Imagine invalidă",
-    "Loading" : "Loading",
-    "Name" : "Nume",
-    "Title" : "Titlu",
+    "All contacts" : "Toate contactele",
+    "Contacts" : "Contacte",
+    "Loading contacts …" : "Se încarcă contactele ...",
+    "Loading …" : "Se încarcă…",
     "Download" : "Descărcare",
-    "Delete" : "Șterge",
-    "Cancel" : "Anulează",
-    "Address book" : "Listă de contacte",
     "Groups" : "Grupuri",
-    "New contact" : "Contact nou ",
-    "No results" : "Niciun rezultat",
+    "Group name" : "Numele grupului",
     "Rename" : "Redenumește",
     "Enabled" : "Activat",
     "Disabled" : "Dezactivat",
+    "Delete" : "Șterge",
     "Copy link" : "Copiază linkul",
     "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
     "No users or groups" : "Nu sunt utilizatori sau grupuri",
@@ -26,7 +21,18 @@ OC.L10N.register(
     "First name" : "Prenume",
     "Last name" : "Nume",
     "Display name" : "Nume afișat",
+    "Invalid image" : "Imagine invalidă",
+    "Name" : "Nume",
+    "Title" : "Titlu",
+    "Cancel" : "Anulează",
+    "Address book" : "Listă de contacte",
+    "New contact" : "Contact nou ",
+    "No results" : "Niciun rezultat",
+    "Close" : "Închide",
+    "Import" : "Importă",
     "Not grouped" : "Negrupate",
+    "Email" : "Email",
+    "Contact" : "Contact",
     "Nickname" : "Pseudonim",
     "Detailed name" : "Nume detaliat",
     "Additional names" : "Nume adiționale",
@@ -48,7 +54,6 @@ OC.L10N.register(
     "Birthday" : "Zi de naștere",
     "Anniversary" : "Aniversare",
     "Date of death" : "Data decesului",
-    "Email" : "Email",
     "Instant messaging" : "Mesagerie instantă",
     "Phone" : "Telefon",
     "Mobile" : "Mobil",
@@ -61,7 +66,6 @@ OC.L10N.register(
     "Car" : "Mașina",
     "Work pager" : "Pager de serviciu",
     "Social network" : "Rețea socială",
-    "Relationship" : "Legătură",
     "Spouse" : "Soție",
     "Child" : "Copil",
     "Mother" : "Mamă",
@@ -74,7 +78,6 @@ OC.L10N.register(
     "Colleague" : "Coleg",
     "Manager" : "Director",
     "Assistant" : "Asistent",
-    "Contact" : "Contact",
     "Gender" : "Sex",
     "Female" : "Femeie",
     "Male" : "Bărbat",
