@@ -1,47 +1,21 @@
 OC.L10N.register(
     "contacts",
     {
-    "All contacts" : "Të gjithë kontaktet",
     "Details" : "Detajet",
+    "All contacts" : "Të gjithë kontaktet",
     "Contacts" : "Kontaktet",
     "A contacts app for Nextcloud" : "Një aplikacion kontaktesh për Nextcloud",
     "Copy to full name" : "Kopje të emrit të plotë ",
     "Omit year" : "Shmang vitin",
-    "Add new property" : "Shto karakteristikë të re",
-    "Choose property type" : "Zgjidh llojin e  karakteristikës",
-    "Upload a new picture" : "Ngarko një foto të re",
-    "Download picture" : "Shkarko foton",
-    "Delete picture" : "Fshi foton",
-    "Choose from files" : "Zgjidh nga skedarët",
-    "Invalid image" : "Figurë e pavlefshme",
-    "Image is too big (max 1MB)." : "Imazhi është shumë i madh (maksimumi 1MB).",
-    "Pick an avatar" : "Zgjidh një avatar",
-    "Error while processing the picture." : "Gabim gjatë procesimit të figurës.",
-    "No contact selected" : "Nuk është zgjedhur asnjë kontakt",
-    "Select a contact on the list to begin" : "Zgjidh një kontakt nga lista për të filluar",
-    "Name" : "Emri",
-    "Company" : "Kompania",
-    "Title" : "Titulli",
-    "This contact was broken and received a fix. Please review the content and click here to save it." : "Ky kontakt ishte prishur dhe u rregullua. Ju lutem rishikoni përmbajtjen dhe klikoni këtu për ta ruajtur atë.",
+    "Loading contacts …" : "Duke ngarkuar kontaktet ...",
     "Download" : "Shkarko",
-    "Generate QR Code" : "Gjeneroni Kodin QR",
-    "Delete" : "Fshije",
-    "Cancel" : "Anullo",
-    "This contact is not yet synced. Edit it to save it to the server." : "Ky kontakt nuk është sinkronizuar akoma. Përditësojeni atë për ta ruajtur në server.",
-    "This contact is in read-only mode. You do not have permission to edit this contact." : "Ky kontakt është në gjendjen vetëm-lexo. Ju nuk keni të drejtë ta ndryshoni këtë kontakt.",
-    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakti që po përpiqeni të përditësoni, ka ndryshuar. Ju lutem rifreskoni manualisht kontaktin. Çdo ndryshim i mëtejshëm nuk do të ruhet.",
-    "Address book" : "Libri i adresave",
     "Groups" : "Grupe",
-    "New contact" : "Kontakt i ri",
-    "Syntax error. Cannot open the contact." : "Gabim sintakse. Kontakti nuk mund të hapet.",
-    "No results" : "Asnjë rezultat",
-    "Select type" : "Zgjidhni llojin",
-    "Select Date" : "Zgjidhni Datën",
-    "Add contact in group" : "Shto kontaktin në grup",
-    "Last modified" : "Ndryshuar së fundmi",
+    "Group name" : "Emër grupi",
     "Rename" : "Riemëro",
     "Enabled" : "I aktivizuar",
     "Disabled" : "I çaktivizuar",
+    "Delete" : "Fshije",
+    "Copied" : "Kopjuar",
     "Copy link" : "Kopjo linkun",
     "Share with users or groups" : "Nda me përdoruesit ose grupet",
     "can edit" : "mund të modifikoni",
@@ -49,11 +23,41 @@ OC.L10N.register(
     "First name" : "Emër",
     "Last name" : "Mbiemër",
     "Display name" : "Shfaq emrin",
-    "Group name" : "Emër grupi",
-    "Loading contacts …" : "Duke ngarkuar kontaktet ...",
-    "Not grouped" : "I pagrupuar",
+    "Last modified" : "Ndryshuar së fundmi",
+    "Add new property" : "Shto karakteristikë të re",
+    "Choose property type" : "Zgjidh llojin e  karakteristikës",
+    "Upload a new picture" : "Ngarko një foto të re",
+    "Download picture" : "Shkarko foton",
+    "Delete picture" : "Fshi foton",
+    "Invalid image" : "Figurë e pavlefshme",
+    "Image is too big (max 1MB)." : "Imazhi është shumë i madh (maksimumi 1MB).",
+    "Pick an avatar" : "Zgjidh një avatar",
+    "Error while processing the picture." : "Gabim gjatë procesimit të figurës.",
+    "Avatar already up to date" : "Avatari është i përditësuar.",
+    "Avatar download failed" : "Shkarkimi i avatarit dështoi.",
+    "No contact selected" : "Nuk është zgjedhur asnjë kontakt",
+    "Select a contact on the list to begin" : "Zgjidh një kontakt nga lista për të filluar",
+    "Name" : "Emri",
+    "Company" : "Kompania",
+    "Title" : "Titulli",
+    "This contact was broken and received a fix. Please review the content and click here to save it." : "Ky kontakt ishte prishur dhe u rregullua. Ju lutem rishikoni përmbajtjen dhe klikoni këtu për ta ruajtur atë.",
+    "Cancel" : "Anullo",
+    "This contact is not yet synced. Edit it to save it to the server." : "Ky kontakt nuk është sinkronizuar akoma. Përditësojeni atë për ta ruajtur në server.",
+    "This contact is in read-only mode. You do not have permission to edit this contact." : "Ky kontakt është në gjendjen vetëm-lexo. Ju nuk keni të drejtë ta ndryshoni këtë kontakt.",
+    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakti që po përpiqeni të përditësoni, ka ndryshuar. Ju lutem rifreskoni manualisht kontaktin. Çdo ndryshim i mëtejshëm nuk do të ruhet.",
+    "Address book" : "Libri i adresave",
+    "New contact" : "Kontakt i ri",
+    "Syntax error. Cannot open the contact." : "Gabim sintakse. Kontakti nuk mund të hapet.",
+    "The contact doesn't exists anymore on the server." : "Kontakti nuk ekziston më në server.",
+    "No results" : "Asnjë rezultat",
+    "Select type" : "Zgjidhni llojin",
+    "Select Date" : "Zgjidhni Datën",
+    "Add contact in group" : "Shto kontaktin në grup",
     "Close" : "Mbylleni",
     "Import" : "Import",
+    "Not grouped" : "I pagrupuar",
+    "Email" : "Email",
+    "Contact" : "Kontakt",
     "Nickname" : "Nofkë",
     "Detailed name" : "Emri i hollësishëm",
     "Additional names" : "Emra shtesë",
@@ -75,7 +79,6 @@ OC.L10N.register(
     "Birthday" : "Datëlindje",
     "Anniversary" : "Përvjetor",
     "Date of death" : "Datë vdekjeje",
-    "Email" : "Email",
     "Instant messaging" : "Shkëmbim i atypëratyshëm mesazhesh",
     "Phone" : "Telefon",
     "Mobile" : "Celular",
@@ -98,7 +101,6 @@ OC.L10N.register(
     "Colleague" : "Koleg/e",
     "Manager" : "Manaxher/e",
     "Assistant" : "Asistent/e",
-    "Contact" : "Kontakt",
     "Agent" : "Agjent",
     "Emergency" : "Emergjencë",
     "Co-worker" : "Koleg",
