@@ -1,18 +1,46 @@
 OC.L10N.register(
     "contacts",
     {
-    "All contacts" : "Всі контакти",
     "Details" : "Деталі",
+    "All contacts" : "Всі контакти",
     "Contacts" : "Контакти",
     "A contacts app for Nextcloud" : "Застосунок для керування контактами для Nextcloud",
     "Copy to full name" : "Копіювати до повного імени",
     "Omit year" : "Не включати рік",
+    "Loading contacts …" : "Завантаження контактів …",
+    "Loading …" : "Завантаження...",
+    "Download" : "Завантажити",
+    "Groups" : "Групи",
+    "Group name" : "Ім'я групи",
+    "Rename" : "Перейменувати",
+    "Enabled" : "Увімкнено",
+    "Disabled" : "Вимкнено",
+    "Delete" : "Вилучити",
+    "Copied" : "Скопійовано",
+    "Copy link" : "Копіювати посилання",
+    "Toggling of address book was not successful" : "Не вдалося перемкнути адресну книгу",
+    "This will delete the address book and every contacts within it" : "Це призведе до вилучення адресної книги та контактів у ній",
+    "Deletion of address book was not successful." : "Не вдалося вилучити адресну книгу",
+    "Renaming of address book was not successful." : "Не вдалося перейменувати адресну книгу",
+    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Спільний доступ з {num} об'єктом","Спільний доступ з {num} об'єктами","Спільний доступ з {num} об'єктами","Спільний доступ з {num} об'єктами"],
+    "Share with users or groups" : "Поділитися з користувачем або групою",
+    "No users or groups" : "Жодного користувача або групм",
+    "can edit" : "може редагувати",
+    "Import contacts" : "Імпорт контактів",
+    "Select local file" : "Виберіть локальний файл",
+    "Importing is disabled because there are no address books available" : "Імпорт недоступний, оскільки відсутні адресні книги",
+    "Choose a vCard file to import" : "Виберіть файл vCard для імпорту",
+    "Address book name" : "Назва адресної книги",
+    "First name" : "Ім'я",
+    "Last name" : "Прізвище",
+    "Display name" : "Ім'я для відображення",
+    "Last modified" : "Останні зміни",
+    "Sort by {sorting}" : "Впорядкувати за {sorting}",
     "Add new property" : "Додати нову властивість",
     "Choose property type" : "Обрати тип властивості",
     "Upload a new picture" : "Завантажити нове зображення",
     "Download picture" : "Завантажити зображення",
     "Delete picture" : "Вилучити зображення",
-    "Choose from files" : "Обрати з файлу",
     "Invalid image" : "Невірне зображення",
     "Image is too big (max 1MB)." : "Зображення завелике (максимум 1МБ).",
     "Pick an avatar" : "Оберіть аватарку",
@@ -23,11 +51,7 @@ OC.L10N.register(
     "Company" : "Компанія",
     "Title" : "Заголовок",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "Дані цього контакту було пошкоджено, а потім виправлено. Будь ласка, перегляньте вміст та натисніть тут для збереження.",
-    "Download" : "Завантажити",
     "Clone contact" : "Клонувати контакт",
-    "Generate QR Code" : "Створити QR код",
-    "Delete" : "Вилучити",
-    "Contact vCard as qrcode" : "vCard контакту як QR-код",
     "Pick an address book" : "Виберіть адресну книгу",
     "Select address book" : "Виберіть адресну книгу",
     "Cancel" : "Скасувати",
@@ -35,54 +59,24 @@ OC.L10N.register(
     "This contact is in read-only mode. You do not have permission to edit this contact." : "Доступ до цього контакту лише у режимі читання. У вас відсутні права на редагування.",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Дані контакту, які ви намагаєтеся відредагувати, змінено. Будь ласка, вручну оновіть контакт. Усі подальші зміни буде проігноровано.",
     "Address book" : "Адресна книга",
-    "Groups" : "Групи",
     "New contact" : "Новий контакт",
     "Syntax error. Cannot open the contact." : "Синтаксична помилка. Неможливо відкрити контакт.",
     "An error occurred while trying to move the contact" : "Помилка під час переміщення контакт",
     "An error occurred while trying to copy the contact" : "Помилка під час копіювання контакту",
-    "Loading …" : "Завантаження...",
     "No results" : "Немає результатів",
     "Select type" : "Виберіть вид",
     "Select Date" : "Вкажіть дату",
     "Add contact in group" : "Додати контакт до групи",
-    "Last modified" : "Останні зміни",
     "Select option" : "Виберіть параметр",
-    "Rename" : "Перейменувати",
-    "Enabled" : "Увімкнено",
-    "Disabled" : "Вимкнено",
-    "Copied" : "Скопійовано",
-    "Can not copy" : "Неможливо скопіювати",
-    "Copy link" : "Копіювати посилання",
-    "Toggling of address book was not successful" : "Не вдалося перемкнути адресну книгу",
-    "This will delete the address book and every contacts within it" : "Це призведе до вилучення адресної книги та контактів у ній",
-    "Delete {addressbook} ?" : "Вилучити {addressbook}?",
-    "Deletion of address book was not successful." : "Не вдалося вилучити адресну книгу",
-    "Renaming of address book was not successful." : "Не вдалося перейменувати адресну книгу",
-    "Address book copied to clipboard" : "Адресну книгу скопійовано",
-    "Address book was not copied to clipboard." : "Адресну книгу не скопійовано",
-    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Спільний доступ з {num} об'єктом","Спільний доступ з {num} об'єктами","Спільний доступ з {num} об'єктами","Спільний доступ з {num} об'єктами"],
-    "Share with users or groups" : "Поділитися з користувачем або групою",
-    "No users or groups" : "Жодного користувача або групм",
-    "can edit" : "може редагувати",
-    "Import contacts" : "Імпорт контактів",
-    "Select local file" : "Виберіть локальний файл",
-    "Import from files" : "Імпорт з файлів",
-    "Importing is disabled because there are no address books available" : "Імпорт недоступний, оскільки відсутні адресні книги",
-    "Choose a vCard file to import" : "Виберіть файл vCard для імпорту",
-    "Address book name" : "Назва адресної книги",
-    "First name" : "Ім'я",
-    "Last name" : "Прізвище",
-    "Display name" : "Ім'я для відображення",
-    "Sort by {sorting}" : "Впорядкувати за {sorting}",
-    "Group name" : "Ім'я групи",
-    "Loading contacts …" : "Завантаження контактів …",
-    "Not grouped" : "Не згруповані",
     "Unable to create the contact." : "Неможливо додати контакт.",
     "Contact not found" : "Контакт не знайдено",
     "Close" : "Закрити",
     "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["Імпорт %n контакту до {addressbook}","Імпорт %n контактів до {addressbook}","Імпорт %n контактів до {addressbook}","Імпорт %n контактів до {addressbook}"],
     "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["Виконано імпорт %n контакту до {addressbook}","Виконано імпорт %n контактів до {addressbook}","Виконано імпорт %n контактів до {addressbook}","Виконано імпорт %n контактів до {addressbook}"],
     "Import" : "Імпорт",
+    "Not grouped" : "Не згруповані",
+    "Email" : "E-mail",
+    "Contact" : "Контакт",
     "Nickname" : "Прізвисько",
     "Detailed name" : "Повне ім'я",
     "Additional names" : "Додаткові імена",
@@ -105,7 +99,6 @@ OC.L10N.register(
     "Birthday" : "День народження",
     "Anniversary" : "Річниця",
     "Date of death" : "Дата смерті",
-    "Email" : "E-mail",
     "Instant messaging" : "Швидкі повідомлення",
     "Phone" : "Телефон",
     "Mobile" : "Мобільний",
@@ -131,7 +124,6 @@ OC.L10N.register(
     "Colleague" : "Колега",
     "Manager" : "Менеджер",
     "Assistant" : "Асистент",
-    "Contact" : "Контакт",
     "Agent" : "Агент",
     "Emergency" : "У разі небезпеки",
     "Co-worker" : "Колега",
