@@ -1,14 +1,86 @@
 OC.L10N.register(
     "contacts",
     {
-    "All contacts" : "全部联系人",
     "Details" : "详情",
+    "All contacts" : "全部联系人",
     "Contacts" : "联系人",
     "A contacts app for Nextcloud" : "适用于 Nextcloud 的联系人应用",
     "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "“日历”是 Nextcloud CalDav 服务器的一个用户界面应用。通过使用此应用，您可以在不同的设备上同步您的活动并进行在线编辑。\n\n* 🚀 **集成了其他的 Nextcloud 应用！** 现在仅仅集成了联系人功能 - 将来将会集成更多。\n* 🌐 **支持WebCal！** 想要在您的日历上看到您最喜爱的球队的比赛时间？没问题！\n* 🙋 **参与人功能！** 邀请他人参与您的活动。\n* 🙈 **我们不是在做无用功！** 基于出色的 [davclient.js](https://github.com/evert/davclient.js), [ical.js](https://github.com/mozilla-comm/ical.js) 和 [fullcalendar](https://github.com/fullcalendar/fullcalendar) 库开发.",
     "Copy to full name" : "复制到全名",
     "Omit year" : "忽略年份",
     "Allow updating avatars from social media" : "允许从社交媒体资料更新头像",
+    "Please select a circle" : "请选择一个圈子",
+    "Loading circle …" : "正在加载圈子 ...",
+    "Your request to join this circle is pending approval" : "你加入这个圈子的请求正在等待批准 ",
+    "You are not a member of {circle}" : "你并非 {circle} 的成员",
+    "There was an error fetching the member list" : "获取成员列表时发生一个错误",
+    "Loading contacts …" : "加载联系人…",
+    "There are no contacts yet" : "尚无联系人",
+    "Create contact" : "创建联系人",
+    "There are no contacts in this group" : "该群组中没有联系人",
+    "Create contacts" : "新建联系人",
+    "Add contacts" : "添加联系人",
+    "Loading …" : "正在加载…",
+    "Add member" : "添加成员",
+    "Leave circle" : "离开圈子",
+    "Delete circle" : "删除圈子",
+    "Download" : "下载",
+    "Groups" : "群组",
+    "Create a new group" : "新建一个群组",
+    "Group name" : "分组名称",
+    "Circles" : "圈子",
+    "Create a new circle" : "新建一个圈子",
+    "Show all groups" : "显示所有小组",
+    "Collapse groups" : "折叠小组",
+    "Show all circles" : "显示所有圈子",
+    "Collapse circles" : "折叠圈子",
+    "This group already exists" : "该群组已存在",
+    "This circle already exists" : "这个圈子已经存在",
+    "An error happened during the creation of the circle" : "创建圈子时发生一个错误",
+    "Rename" : "重命名",
+    "Enabled" : "已启用",
+    "Disabled" : "已禁用",
+    "Delete" : "删除",
+    "Copied" : "已复制",
+    "Cannot copy" : "无法复制",
+    "Copy link" : "复制链接",
+    "Toggling of address book was not successful" : "通讯录切换不成功",
+    "This will delete the address book and every contacts within it" : "这将删除通讯录和其中的每个联系人",
+    "Delete {addressbook}?" : "删除 {addressbook} ？",
+    "Deletion of address book was not successful." : "通讯录删除不成功",
+    "Renaming of address book was not successful." : "通讯录重命名不成功",
+    "_Shared with {num} entity_::_Shared with {num} entities_" : ["与 {num} 个实体共享"],
+    "Share with users or groups" : "和用户或者组群共享",
+    "No users or groups" : "无用户或群组",
+    "can edit" : "可编辑",
+    "Unable to delete the share" : "无法删除共享",
+    "Unable to change permissions" : "无法更改权限",
+    "Import contacts" : "导入联系人",
+    "Import into the {addressbookName} address book" : "导入 {addressbookName} 通讯录",
+    "Select local file" : "选择本地文件",
+    "Import from Files" : "从文件导入",
+    "Importing is disabled because there are no address books available" : "导入已被禁用，因为没有可用的地址簿",
+    "Choose a vCard file to import" : "选择要导入的 vCard（电子名片） 文件",
+    "Address book name" : "地址簿名称",
+    "An error occurred, unable to create the address book" : "发生错误，无法创建通讯录",
+    "First name" : "名",
+    "Last name" : "姓",
+    "Phonetic first name" : "语音名字",
+    "Phonetic last name" : "语音姓氏",
+    "Display name" : "显示名称",
+    "Last modified" : "上一次更改",
+    "Sort by {sorting}" : "以 {sorting} 排序",
+    "Update avatars from social media" : "从社交媒体更新头像",
+    "(refreshed once per week)" : "(每周刷新)",
+    "An error happened during the config change" : "更改配置时发生一个错误",
+    "Circle name" : "圈子名称",
+    "Circle owned by {owner}" : "圈子所有者为  {owner}",
+    "Request to join" : "请求加入",
+    "Description" : "描述",
+    "There is no description for this circle" : "这个圈子没有描述",
+    "Enter a description for the circle" : "为这个圈子输入一个描述",
+    "An error happened during description sync" : "描述同步期间发生一个错误",
+    "An error happened during name sync" : "名称同步期间发生了一个错误",
     "Add new property" : "新增属性",
     "Choose property type" : "选择属性类型",
     "Upload a new picture" : "上传一张新的图片",
@@ -16,7 +88,6 @@ OC.L10N.register(
     "Get from " : "获取自",
     "Download picture" : "下载图片",
     "Delete picture" : "删除图片",
-    "Choose from files" : "从文件中选择",
     "Invalid image" : "无效的图像",
     "Image is too big (max 1MB)." : "图片过大(最大1MB)",
     "Pick an avatar" : "选择一个头像",
@@ -30,11 +101,9 @@ OC.L10N.register(
     "Company" : "公司",
     "Title" : "头衔",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "此联系人已损坏但接收到了一个修复。请查看内容并点击这里以保存它。",
-    "Download" : "下载",
     "Clone contact" : "克隆联系人",
     "Generate QR Code" : "生成二维码",
-    "Delete" : "删除",
-    "Contact vCard as qrcode" : "联系人名片二维码",
+    "Contact vCard as QR code" : "联系人名片作为二维码",
     "Pick an address book" : "选择一个地址簿",
     "Select address book" : "选择地址簿",
     "Cancel" : "取消",
@@ -42,75 +111,53 @@ OC.L10N.register(
     "This contact is in read-only mode. You do not have permission to edit this contact." : "此联系人处于只读模式。 您无权编辑此联系人。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您尝试编辑的联系人已更改。 请手动刷新联系人。 任何进一步的编辑都不会被保存。",
     "Address book" : "地址簿",
-    "Groups" : "群组",
     "New contact" : "新建联系人",
     "Syntax error. Cannot open the contact." : "语法错误。不能打开联系人。",
     "The contact doesn't exists anymore on the server." : "此联系人不再存在于此服务器上。",
     "Unable to retrieve the contact from the server, please check your network connection." : "无法从服务器取回联系人，请检查你的网络连接。",
     "An error occurred while trying to move the contact" : "尝试移动联系人时出错",
     "An error occurred while trying to copy the contact" : "尝试复制联系人时出错",
+    "Add to {group}" : "添加到 {group}",
     "Remove {type}" : "移除 {类型}",
     "Search {types}" : "搜索 {类型}",
-    "Loading …" : "正在加载…",
-    "List is empty" : "列表是空的",
+    "Search for people to add" : "搜索要添加的人",
     "No results" : "无结果",
     "Add to group" : "添加到群组",
     "Add {type}" : "添加  {类型}",
+    "New circle name" : "新的圈子名称",
+    "Personal circle" : "个人圈子",
+    "This circle will only be visible to you. Other members will not be able to see or use it." : "这个圈子仅对你可见。其他成员无法看见或使用它",
+    "Local circle" : "本地圈子",
+    "This circle will not be shared with the other instances of the global scale" : "这个圈子不会与 GlobalScale 的其他实例共享 ",
+    "Create circle" : "创建圈子",
+    "Loading members list …" : "加载成员列表中 ...",
+    "The list of members is only visible to members of this circle" : "成员列表仅对这个圈子的成员可见",
+    "There is no member in this circle" : "这个圈子没有成员",
+    "Add members" : "添加成员",
+    "Show circle details" : "显示圈子详情",
+    "Add to {circle}" : "添加到 {circle}",
+    "Unable to get the recommendations list" : "无法获取推荐列表",
+    "Unable to get the results" : "无法获得结果",
+    "Some members could not be added" : "无法添加一些成员",
+    "There was an issue adding members to the circle" : "添加成员到这个圈子时出错",
+    "Accept membership request" : "接收成员身份请求",
+    "Reject membership request" : "拒绝成员身份请求",
+    "Manage level" : "管理级别",
+    "Remove member" : "删除成员",
+    "Pending" : "待定",
+    "Promote as sole owner" : "提升为唯一所有人",
+    "Promote to {level}" : "提升为 {level}",
+    "Demote to {level}" : "降级为 {level}",
+    "Could not delete the member {displayName}" : "无法删除成员 {displayName}",
+    "Could not change the member level to {level}" : "无法更改成员级别到 {level}",
+    "Could not accept membership request" : "无法接受成员身份请求",
     "Select type" : "选择类型",
     "Select Date" : "选择日期",
     "Add contact in group" : "添加联系人到群组",
-    "Last modified" : "上一次更改",
     "Select option" : "选择选项",
-    "Rename" : "重命名",
-    "Enabled" : "已启用",
-    "Disabled" : "已禁用",
-    "Copied" : "已复制",
-    "Can not copy" : "无法复制",
-    "Copy link" : "复制链接",
-    "Toggling of address book was not successful" : "通讯录切换不成功",
-    "This will delete the address book and every contacts within it" : "这将删除通讯录和其中的每个联系人",
-    "Delete {addressbook} ?" : "删除 {addressbook} ？",
-    "Deletion of address book was not successful." : "通讯录删除不成功",
-    "Renaming of address book was not successful." : "通讯录重命名不成功",
-    "Address book copied to clipboard" : "已复制通讯录到剪贴板",
-    "Address book was not copied to clipboard." : "通讯录未被复制到剪贴板。",
-    "_Shared with {num} entity_::_Shared with {num} entities_" : ["与 {num} 个实体共享"],
-    "Share with users or groups" : "和用户或者组群共享",
-    "No users or groups" : "无用户或群组",
-    "can edit" : "可编辑",
-    "Unable to delete the share" : "无法删除共享",
-    "Unable to change permissions" : "无法更改权限",
-    "Import contacts" : "导入联系人",
-    "Import into the {addressbookName} addressbook" : "导入到 {addressbookName} 通讯录中",
-    "Select local file" : "选择本地文件",
-    "Import from files" : "从文件导入",
-    "Importing is disabled because there are no address books available" : "导入已被禁用，因为没有可用的地址簿",
-    "Choose a vCard file to import" : "选择要导入的 vCard（电子名片） 文件",
-    "Address book name" : "地址簿名称",
-    "An error occurred, unable to create the address book" : "发生错误，无法创建通讯录",
-    "First name" : "名",
-    "Last name" : "姓",
-    "Phonetic first name" : "语音名字",
-    "Phonetic last name" : "语音姓氏",
-    "Display name" : "显示名称",
-    "Sort by {sorting}" : "以 {sorting} 排序",
-    "Update avatars from social media" : "从社交媒体更新头像",
-    "(refreshed once per week)" : "(每周刷新)",
-    "Add contacts" : "添加联系人",
-    "+ New group" : "+ 新群组",
-    "Create a new group" : "新建一个群组",
-    "Group name" : "分组名称",
-    "Loading contacts …" : "加载联系人…",
-    "There are no contacts yet" : "尚无联系人",
-    "Create contact" : "创建联系人",
-    "There are no contacts in this group" : "该群组中没有联系人",
-    "Create contacts" : "新建联系人",
-    "Not grouped" : "未分组",
-    "Recently contacted" : "最近联系",
     "Unable to create the contact." : "未能成功创建联系人。",
     "Contact not found" : "未找到联系人",
-    "Group not found" : "找不到群组",
-    "This group already exists" : "该群组已存在",
+    "Group {group} not found" : "未找到小组 {group} ",
     "Close" : "关闭",
     "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 位联系人已添加到 {name}"],
     "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["正在添加 {success} 位联系人到 {name}"],
@@ -118,6 +165,40 @@ OC.L10N.register(
     "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["正在导入 %n 个联系人到 {addressbook}"],
     "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["已将 %n 个联系人导入到 {addressbook}"],
     "Import" : "导入",
+    "Could not copy" : "无法复制",
+    "Join circle" : "加入圈子",
+    "You are about to leave {circle}.\nAre you sure?" : "你即将离开 {circle}\n确定吗？",
+    "Please confirm circle leave" : "请确认退圈",
+    "Could not leave the circle {displayName}" : "无法离开圈子 {displayName}",
+    "Unable to join the circle" : "无法加入这个圈子",
+    "You are about to delete {circle}.\nAre you sure?" : "你即将删除 {circle}\n确定吗？",
+    "Please confirm circle deletion" : "请确认删除操作",
+    "Unable to delete the circle" : "无法删除圈子",
+    "Link copied to the clipboard" : "链接已复制到剪贴板",
+    "Could not copy link to the clipboard." : "无法复制链接到剪贴板",
+    "Not grouped" : "未分组",
+    "Recently contacted" : "最近联系",
+    "Circles allow you to create groups with other users on a Nextcloud instance and share with them." : "Circles允许你在 Nextcloud 实例上与其他用户创建组并与他们分享。",
+    "Circle" : "圈子",
+    "User" : "用户",
+    "Group" : "小组",
+    "Email" : "电子邮件",
+    "Contact" : "联系",
+    "Member" : "成员",
+    "Moderator" : "版主",
+    "Admin" : "管理员",
+    "Owner" : "所有者",
+    "Invites" : "邀请",
+    "Anyone can request membership" : "任何人均可请求成员资格",
+    "Members need to accept invitation" : "成员需要接受邀请",
+    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "成员资格必须由一名版主进行确认/接受 (需要开放)",
+    "Members can also invite" : "成员也可以进行邀请",
+    "Visibility" : "可见性",
+    "Visible to everyone" : "对所有人可见",
+    "Circle membership" : "圈子成员资格",
+    "Prevent circle from being a member of another circle" : "防止圈子成为另一个圈子的成员",
+    "Users" : "用户",
+    "Emails" : "电子邮件",
     "Nickname" : "昵称",
     "Detailed name" : "全名",
     "Additional names" : "其他名称",
@@ -140,7 +221,6 @@ OC.L10N.register(
     "Birthday" : "生日",
     "Anniversary" : "周年",
     "Date of death" : "去世日期",
-    "Email" : "电子邮件",
     "Instant messaging" : "即时通讯",
     "Phone" : "电话",
     "Mobile" : "手机",
@@ -168,7 +248,6 @@ OC.L10N.register(
     "Manager" : "经理",
     "Assistant" : "助理",
     "Related contacts" : "相关联系人",
-    "Contact" : "联系",
     "Agent" : "代理",
     "Emergency" : "紧急",
     "Co-worker" : "同事",
@@ -180,6 +259,9 @@ OC.L10N.register(
     "Timezone" : "时区",
     "Spoken languages" : "口语",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 个联系人读取失败"],
+    "Some circle(s) an error occurred. Check the console for more details." : "一些圈子出错了。更多详情见控制台",
+    "Unable to create circle {circleName}" : "无法创建圈子 {circleName}",
+    "Unable to delete circle {circleId}" : "无法删除圈子 {circleId}",
     "Unable to delete contact" : "无法删除联系人",
     "Your web browser is out of date" : "您的浏览器版本太旧",
     "This application is not compatible with Internet Explorer" : "此应用与Internet Explorer不兼容"
